#
# spec file for package python-typing
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without tests

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-typing
Version:        3.7.4
Release:        lp151.3.3.1
Summary:        Type Hints for Python
License:        Python-2.0
Group:          Development/Languages/Python
Url:            https://docs.python.org/3.5/library/typing.html
Source:         https://files.pythonhosted.org/packages/source/t/typing/typing-%{version}.tar.gz
Patch0:         isinstance_w_gen_prot_subcls.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# Test requirements
%if %{with tests} && 0%{?suse_version} > 1320
BuildRequires:  python3-testsuite
%endif
BuildArch:      noarch

%if "%python3_bin_suffix" != ""
%if %{python3_version_nodots} > 34
%define skip_python3 1
%endif
%endif

%python_subpackages

%description
Backport of the standard library typing module for Python versions older than 3.5.

%prep
%setup -q -n typing-%{version}
%autopatch -p1

ln -s python2 python_%{python2_bin_suffix}
%if "%python3_bin_suffix" != ""
ln -s src python_%{python3_bin_suffix}
%endif

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%if %{with tests}
%check
export PYTHONDONTWRITEBYTECODE=1
%python_exec python_%{$python_bin_suffix}/test_typing.py
%endif

%files %{python_files}
%doc README.rst
%if 0%{?leap_version} >= 420200 || 0%{?suse_version} > 1320
%license LICENSE
%else
%doc LICENSE
%endif
%{python_sitelib}/*

%changelog
* Thu May 14 2020 Matej Cepl <mcepl@suse.com>
- Update to 3.7.4 (jsc#SLE-12548, bsc#1162547):
  - Fix subclassing builtin protocols on older Python versions
  - Move Protocol, runtime_checkable, Final, final, Literal,
    and TypedDict to typing
  - Add support for Python 3.8 in typing_extensions
  - Unify the implementation of annotated in src_py2 and src_py3
  - Add Annotated in python2
  - Pep 593 py3
  - Drop support of Python 3.3
  - [typing-extensions] Simple implementation for IntVar
  - Add a python 3.7+ version of Annotated to typing_extensions
  - Add SupportsIndex
  - Add TypedDict to typing_extensions
  - Add Final to the README
  - Run the tests using the current Python executable
  - Fix GeneralMeta.__instancecheck__() for old style classes
  - Add Literal[...] types to typing_extensions
  - Fix instance/subclass checks of functions against runtime protocols.
  - Bump typing_extension version
  - Improve PyPI entry for typing_extensions
  - Add Final to typing_extensions
  - include license file for typing-extensions and in wheels
  - Fix IO.closed to be property
  - Backport Generic.__new__ fix
  - Bump typing_extensions version before release
  - Add missing 'NoReturn' to __all__ in typing.py
  - Add annotations to NamedTuple children __new__ constructors
  - Fix typing_extensions to support PEP 560
  - Pass *args and **kwargs to superclass in Generic.__new__
  - Fix interaction between generics and __init_subclass__
  - Fix protocols in unions (runtime problem)
  - Fix interaction between typing_extensions and collections.abc
  - Override subclass check for the singledispatch library
  - Fix copying generic instances in Python 3
  - Switch to setuptools in typing_extensions
  - Add class Protocol and @runtime to typing extensions
  - get_type_hints(): find the right globalns for classes and modules
  - Document the workflow for publishing wheels
  - Make sure copy and deepcopy are returning same class
  - Update pytest and pytest-xdist versions
- Add isinstance_w_gen_prot_subcls.patch to fix failing test
  test_protocol_instance_works (gh#python/typing#656)
* Tue Sep 12 2017 aloisio@gmx.com
- Update to version 3.6.2
- Dropped mod_generics_cache.py (now supplied upstream)
* Tue Aug 15 2017 dmueller@suse.com
- fix build in python2-only environments
* Thu Jul  6 2017 sebix+novell.com@sebix.at
- only build for python3<3.5
* Sun Apr 23 2017 toddrme2178@gmail.com
- Fix license formatting
* Tue Apr 18 2017 toddrme2178@gmail.com
- The last update broke packaging due to dysfunctional testing.
  Provide the missing module from upstream.
* Tue Apr 18 2017 toddrme2178@gmail.com
- Update to 3.6.1
  * Uses python 3.6 version.
- Implement single-spec version
  Note: Some packages require this even on python 3.6.x
* Mon Aug  1 2016 michael@stroeder.com
- initial packaging of release 3.5.2.2
